@@ -21,7 +21,7 @@ class BoundingBox(BaseModel):
     @root_validator
     def between_zero_and_one(cls, values):
         for key in values:
-            if key != "name":
+            if key != "value":
                 if values[key] > 1 or values[key] < 0:
                     raise ValueError(
                         f"{key} must be greater or equal to zero and less than or equal to one."
