@@ -18,3 +18,5 @@ class EvaluationMeta(BaseModel):
     write_to_file: Optional[bool]
     last_file: Optional[bool]
     request_id: Optional[str]
+    prediction_model_name: Optional[str]
+    label_model_name: Optional[str]
