@@ -10,7 +10,7 @@ from typing import Optional
 class Model(BaseModel):
     name: str
     version: Optional[str] = "HEAD"
-    type: Optional[str]
+    type: Optional[str] = "classification"
 
     class Config:
         arbitrary_types_allowed = True
